dispatch_dependency_resolution

Function dispatch_dependency_resolution 

pub async fn dispatch_dependency_resolution(
    client: &Client,
    router: &PartitionRouter,
    eid: &ExecutionId,
    flow_id: Option<&str>,
)
Post-completion dependency dispatch.

After an execution completes/fails/cancels, the engine dispatches resolve_dependency to each downstream child’s {p:N} partition. Reads outgoing edges from the flow partition, then for each downstream child, calls FCALL ff_resolve_dependency on the child’s partition.

If a child is transitioned to terminal (skipped) by the resolution, cascades dispatch for the skipped child’s outgoing edges so that grandchildren don’t wait for the reconciler (up to 15s/level).